@@ -39,6 +39,7 @@ import org.apache.lucene.store.IOContext;
 import org.apache.lucene.store.TrackingDirectoryWrapper;
 import org.apache.lucene.util.Bits;
 import org.apache.lucene.util.BytesRef;
+import org.apache.lucene.util.FixedBitSet;
 import org.apache.lucene.util.IOConsumer;
 import org.apache.lucene.util.IOUtils;
 import org.apache.lucene.util.InfoStream;
@@ -192,7 +193,7 @@ final class ReadersAndUpdates {
 
   public synchronized boolean delete(int docID) throws IOException {
     if (reader == null && pendingDeletes.mustInitOnDelete()) {
-      getReader(IOContext.READ).decRef(); // pass a reader to initialize the pending deletes
+      getReader(IOContext.DEFAULT).decRef(); // pass a reader to initialize the pending deletes
     }
     return pendingDeletes.delete(docID);
   }
@@ -241,7 +242,7 @@ final class ReadersAndUpdates {
   private synchronized CodecReader getLatestReader() throws IOException {
     if (this.reader == null) {
       // get a reader and dec the ref right away we just make sure we have a reader
-      getReader(IOContext.READ).decRef();
+      getReader(IOContext.DEFAULT).decRef();
     }
     if (pendingDeletes.needsRefresh(reader)) {
       // we have a reader but its live-docs are out of sync. let's create a temporary one that we
@@ -321,7 +322,7 @@ final class ReadersAndUpdates {
       }
       final long nextDocValuesGen = info.getNextDocValuesGen();
       final String segmentSuffix = Long.toString(nextDocValuesGen, Character.MAX_RADIX);
-      final IOContext updatesContext = new IOContext(new FlushInfo(info.info.maxDoc(), bytes));
+      final IOContext updatesContext = IOContext.flush(new FlushInfo(info.info.maxDoc(), bytes));
       final FieldInfo fieldInfo = infos.fieldInfo(field);
       assert fieldInfo != null;
       fieldInfo.setDocValuesGen(nextDocValuesGen);
@@ -385,6 +386,12 @@ final class ReadersAndUpdates {
                       return mergedDocValues.advance(target);
                     }
 
+                    @Override
+                    public void intoBitSet(int upTo, FixedBitSet bitSet, int offset)
+                        throws IOException {
+                      mergedDocValues.intoBitSet(upTo, bitSet, offset);
+                    }
+
                     @Override
                     public long cost() {
                       return mergedDocValues.cost();
@@ -432,6 +439,12 @@ final class ReadersAndUpdates {
                       return mergedDocValues.advance(target);
                     }
 
+                    @Override
+                    public void intoBitSet(int upTo, FixedBitSet bitSet, int offset)
+                        throws IOException {
+                      mergedDocValues.intoBitSet(upTo, bitSet, offset);
+                    }
+
                     @Override
                     public long cost() {
                       return mergedDocValues.cost();
@@ -461,6 +474,7 @@ final class ReadersAndUpdates {
     private int docIDOnDisk = -1;
     // docID from our updates
     private int updateDocID = -1;
+    private FixedBitSet scratch;
 
     private final DocValuesInstance onDiskDocValues;
     private final DocValuesInstance updateDocValues;
@@ -526,6 +540,61 @@ final class ReadersAndUpdates {
       } while (hasValue == false);
       return docIDOut;
     }
+
+    @Override
+    public void intoBitSet(int upTo, FixedBitSet bitSet, int offset) throws IOException {
+      if (onDiskDocValues == null) {
+        super.intoBitSet(upTo, bitSet, offset);
+        return;
+      }
+
+      // we need a scratch bitset because the param bitset doesn't allow bits to be cleared.
+      if (scratch == null) {
+        scratch = new FixedBitSet(bitSet.length());
+      } else {
+        // It's OK even if bitset.length() == 0 according the contract.
+        scratch = FixedBitSet.ensureCapacity(scratch, bitSet.length() - 1);
+        scratch.clear();
+      }
+
+      onDiskDocValues.intoBitSet(upTo, scratch, offset);
+      docIDOnDisk = onDiskDocValues.docID();
+
+      for (int doc = updateDocValues.docID(); doc < upTo; doc = updateDocValues.nextDoc()) {
+        if (updateIterator.hasValue()) {
+          scratch.set(doc - offset);
+        } else {
+          scratch.clear(doc - offset);
+        }
+      }
+
+      FixedBitSet.orRange(scratch, 0, bitSet, 0, bitSet.length());
+
+      // Iterate to find out current doc.
+      while (true) {
+        while (updateDocValues.docID() < docIDOnDisk && updateIterator.hasValue() == false) {
+          updateDocValues.nextDoc();
+        }
+        if (docIDOnDisk != NO_MORE_DOCS
+            && updateDocValues.docID() == docIDOnDisk
+            && updateIterator.hasValue() == false) {
+          // value of docIDOnDisk removed
+          docIDOnDisk = onDiskDocValues.nextDoc();
+        } else {
+          break;
+        }
+      }
+
+      // update docIDOut and currentValuesSupplier
+      updateDocID = updateDocValues.docID();
+      if (docIDOnDisk < updateDocID) {
+        docIDOut = docIDOnDisk;
+        currentValuesSupplier = onDiskDocValues;
+      } else {
+        docIDOut = updateDocID;
+        currentValuesSupplier = updateDocValues;
+      }
+    }
   }
 
   private synchronized Set<String> writeFieldInfosGen(
@@ -536,7 +605,7 @@ final class ReadersAndUpdates {
     // HEADER + FOOTER: 40
     // 90 bytes per-field (over estimating long name and attributes map)
     final long estInfosSize = 40 + 90L * fieldInfos.size();
-    final IOContext infosContext = new IOContext(new FlushInfo(info.info.maxDoc(), estInfosSize));
+    final IOContext infosContext = IOContext.flush(new FlushInfo(info.info.maxDoc(), estInfosSize));
     // separately also track which files were created for this gen
     final TrackingDirectoryWrapper trackingDir = new TrackingDirectoryWrapper(dir);
     infosFormat.write(trackingDir, info.info, segmentSuffix, fieldInfos, infosContext);
@@ -708,11 +777,12 @@ final class ReadersAndUpdates {
     return new FieldInfo(
         fi.name,
         fieldNumber,
-        fi.hasVectors(),
+        fi.hasTermVectors(),
         fi.omitsNorms(),
         fi.hasPayloads(),
         fi.getIndexOptions(),
         fi.getDocValuesType(),
+        fi.docValuesSkipIndexType(),
         fi.getDocValuesGen(),
         new HashMap<>(fi.attributes()),
         fi.getPointDimensionCount(),
