@@ -61,7 +61,7 @@ import org.junit.BeforeClass;
 //   - skipTo(doc)
 
 public class TestCodecs extends LuceneTestCase {
-  private static String[] fieldNames = new String[] {"one", "two", "three", "four"};
+  private static final String[] fieldNames = new String[] {"one", "two", "three", "four"};
 
   private static int NUM_TEST_ITER;
   private static final int NUM_TEST_THREADS = 3;
@@ -106,6 +106,7 @@ public class TestCodecs extends LuceneTestCase {
                     storePayloads,
                     indexOptions,
                     DocValuesType.NONE,
+                    DocValuesSkipIndexType.NONE,
                     -1,
                     new HashMap<>(),
                     0,
@@ -231,7 +232,8 @@ public class TestCodecs extends LuceneTestCase {
     }
 
     final FieldInfos.Builder builder =
-        new FieldInfos.Builder(new FieldInfos.FieldNumbers(null, null, Version.LATEST.major));
+        new FieldInfos.Builder(new FieldInfos.FieldNumbers(null, null));
+
     final FieldData field = new FieldData("field", builder, terms, true, false);
     final FieldData[] fields = new FieldData[] {field};
     final FieldInfos fieldInfos = builder.finish();
@@ -294,7 +296,8 @@ public class TestCodecs extends LuceneTestCase {
 
   public void testRandomPostings() throws Throwable {
     final FieldInfos.Builder builder =
-        new FieldInfos.Builder(new FieldInfos.FieldNumbers(null, null, Version.LATEST.major));
+        new FieldInfos.Builder(new FieldInfos.FieldNumbers(null, null));
+
     final FieldData[] fields = new FieldData[NUM_FIELDS];
     for (int i = 0; i < NUM_FIELDS; i++) {
       final boolean omitTF = 0 == (i % 3);
