@@ -33,6 +33,7 @@ import org.apache.lucene.document.SortedNumericDocValuesField;
 import org.apache.lucene.document.SortedSetDocValuesField;
 import org.apache.lucene.document.StringField;
 import org.apache.lucene.index.ExitableDirectoryReader.ExitingReaderException;
+import org.apache.lucene.search.AcceptDocs;
 import org.apache.lucene.search.DocIdSetIterator;
 import org.apache.lucene.search.IndexSearcher;
 import org.apache.lucene.search.PrefixQuery;
@@ -470,7 +471,7 @@ public class TestExitableDirectoryReader extends LuceneTestCase {
                   "vector",
                   TestVectorUtil.randomVector(dimension),
                   5,
-                  leaf.getLiveDocs(),
+                  AcceptDocs.fromLiveDocs(leaf.getLiveDocs(), leaf.maxDoc()),
                   Integer.MAX_VALUE));
     } else {
       KnnVectorValues values = leaf.getFloatVectorValues("vector");
@@ -480,7 +481,7 @@ public class TestExitableDirectoryReader extends LuceneTestCase {
           "vector",
           TestVectorUtil.randomVector(dimension),
           5,
-          leaf.getLiveDocs(),
+          AcceptDocs.fromLiveDocs(leaf.getLiveDocs(), leaf.maxDoc()),
           Integer.MAX_VALUE);
     }
 
@@ -545,7 +546,7 @@ public class TestExitableDirectoryReader extends LuceneTestCase {
                   "vector",
                   TestVectorUtil.randomVectorBytes(dimension),
                   5,
-                  leaf.getLiveDocs(),
+                  AcceptDocs.fromLiveDocs(leaf.getLiveDocs(), leaf.maxDoc()),
                   Integer.MAX_VALUE));
 
     } else {
@@ -556,7 +557,7 @@ public class TestExitableDirectoryReader extends LuceneTestCase {
           "vector",
           TestVectorUtil.randomVectorBytes(dimension),
           5,
-          leaf.getLiveDocs(),
+          AcceptDocs.fromLiveDocs(leaf.getLiveDocs(), leaf.maxDoc()),
           Integer.MAX_VALUE);
     }
 
