@@ -23,6 +23,7 @@ import java.util.Random;
 import org.apache.lucene.index.VectorSimilarityFunction;
 import org.apache.lucene.internal.vectorization.BaseVectorizationTestCase;
 import org.apache.lucene.internal.vectorization.VectorizationProvider;
+import org.apache.lucene.search.DocAndScoreAccBuffer;
 import org.apache.lucene.tests.util.LuceneTestCase;
 import org.apache.lucene.tests.util.TestUtil;
 
@@ -121,6 +122,17 @@ public class TestVectorUtil extends LuceneTestCase {
     expectThrows(IllegalArgumentException.class, () -> VectorUtil.l2normalize(v));
   }
 
+  public void testNormalizeToUnitInterval() {
+    for (int i = 0; i < 100; i++) {
+      // Generates a float in the range [-1.0, 1.0)
+      float f = random().nextFloat() * 2 - 1;
+      float v = VectorUtil.normalizeToUnitInterval(f);
+      assertTrue(v >= 0);
+      assertTrue(v <= 1);
+      assertEquals(Math.max((1 + f) / 2, 0), v, 0.0f);
+    }
+  }
+
   public void testExtremeNumerics() {
     float[] v1 = new float[1536];
     float[] v2 = new float[1536];
@@ -390,6 +402,45 @@ public class TestVectorUtil extends LuceneTestCase {
     return length;
   }
 
+  public void testFilterByScore() {
+    for (int iter = 0; iter < 1_000; ++iter) {
+      int padding = TestUtil.nextInt(random(), 0, 5);
+      DocAndScoreAccBuffer b1 = new DocAndScoreAccBuffer();
+      DocAndScoreAccBuffer b2 = new DocAndScoreAccBuffer();
+      b1.growNoCopy(128 + padding);
+      b2.growNoCopy(128 + padding);
+
+      int doc = 0;
+      for (int i = 0; i < 128 + padding; ++i) {
+        doc += TestUtil.nextInt(random(), 1, 1000);
+        b1.docs[i] = b2.docs[i] = doc;
+        b1.scores[i] = b2.scores[i] = random().nextDouble();
+      }
+
+      double minScoreInclusive = random().nextDouble();
+      int upTo = TestUtil.nextInt(random(), 0, 127);
+      b1.size = slowFilterByScore(b1.docs, b1.scores, minScoreInclusive, upTo);
+      b2.size = VectorUtil.filterByScore(b2.docs, b2.scores, minScoreInclusive, upTo);
+      assertEquals(b1.size, b2.size);
+      assertTrue(Arrays.equals(b1.docs, 0, b1.size, b2.docs, 0, b2.size));
+      // two double array should be exactly the same, so just use simple Arrays.equals
+      assertTrue(Arrays.equals(b1.scores, 0, b1.size, b2.scores, 0, b2.size));
+    }
+  }
+
+  private static int slowFilterByScore(
+      int[] docBuffer, double[] scoreBuffer, double minScoreInclusive, int upTo) {
+    int newSize = 0;
+    for (int i = 0; i < upTo; i++) {
+      if (scoreBuffer[i] >= minScoreInclusive) {
+        docBuffer[newSize] = docBuffer[i];
+        scoreBuffer[newSize] = scoreBuffer[i];
+        newSize++;
+      }
+    }
+    return newSize;
+  }
+
   public void testInt4BitDotProductInvariants() {
     int iterations = atLeast(10);
     for (int i = 0; i < iterations; i++) {
