@@ -19,6 +19,7 @@ package org.apache.lucene.expressions.js;
 import java.io.IOException;
 import java.io.Reader;
 import java.lang.constant.ConstantDescs;
+import java.lang.constant.DirectMethodHandleDesc;
 import java.lang.invoke.MethodHandle;
 import java.lang.invoke.MethodHandleInfo;
 import java.lang.invoke.MethodHandles;
@@ -38,8 +39,8 @@ import java.util.Properties;
 import java.util.function.Function;
 import java.util.function.Supplier;
 import java.util.stream.Stream;
-import org.antlr.v4.runtime.ANTLRInputStream;
 import org.antlr.v4.runtime.BaseErrorListener;
+import org.antlr.v4.runtime.CharStreams;
 import org.antlr.v4.runtime.CommonTokenStream;
 import org.antlr.v4.runtime.DiagnosticErrorListener;
 import org.antlr.v4.runtime.RecognitionException;
@@ -115,27 +116,31 @@ public final class JavascriptCompiler {
       JAVASCRIPT_COMPILER_TYPE = Type.getType(JavascriptCompiler.class),
       THROWABLE_TYPE = Type.getType(Throwable.class);
   private static final Method
-      EXPRESSION_CTOR = getAsmMethod(void.class, "<init>", String.class, String[].class),
+      EXPRESSION_CTOR =
+          getAsmMethod(void.class, ConstantDescs.INIT_NAME, String.class, String[].class),
       EVALUATE_METHOD = getAsmMethod(double.class, "evaluate", DoubleValues[].class),
       DOUBLE_VAL_METHOD = getAsmMethod(double.class, "doubleValue"),
       PATCH_STACK_METHOD =
           getAsmMethod(Throwable.class, "patchStackTrace", Throwable.class, Expression.class);
   private static final Type[] EVALUATE_EXCEPTIONS = new Type[] {Type.getType(IOException.class)};
   private static final Handle DYNAMIC_CONSTANT_BOOTSTRAP_HANDLE =
-      new Handle(
-          Opcodes.H_INVOKESTATIC,
-          JAVASCRIPT_COMPILER_TYPE.getInternalName(),
-          "dynamicConstantBootstrap",
-          MethodType.methodType(
-                  MethodHandle.class, Lookup.class, String.class, Class.class, String.class)
-              .toMethodDescriptorString(),
-          false);
+      getAsmHandle(ConstantDescs.BSM_CLASS_DATA_AT);
 
   /** create an ASM Method object from return type, method name, and parameters. */
   private static Method getAsmMethod(Class<?> rtype, String name, Class<?>... ptypes) {
     return new Method(name, MethodType.methodType(rtype, ptypes).toMethodDescriptorString());
   }
 
+  /** convert a Java direct method handle descriptor to an ASM {@link Handle}. */
+  private static Handle getAsmHandle(DirectMethodHandleDesc dm) {
+    return new Handle(
+        dm.refKind(),
+        Type.getType(dm.owner().descriptorString()).getInternalName(),
+        dm.methodName(),
+        dm.invocationType().descriptorString(),
+        dm.isOwnerInterface());
+  }
+
   final String sourceText;
   final Map<String, MethodHandle> functions;
   final boolean picky;
@@ -231,12 +236,13 @@ public final class JavascriptCompiler {
    * @throws ParseException on failure to compile
    */
   private Expression compileExpression() throws ParseException {
-    final Map<String, Integer> externalsMap = new LinkedHashMap<>();
+    final Map<String, Integer> externalsMap = new LinkedHashMap<>(),
+        constantsMap = new LinkedHashMap<>();
     final ClassWriter classWriter =
         new ClassWriter(ClassWriter.COMPUTE_FRAMES | ClassWriter.COMPUTE_MAXS);
 
     try {
-      generateClass(getAntlrParseTree(), classWriter, externalsMap);
+      generateClass(getAntlrParseTree(), classWriter, externalsMap, constantsMap);
     } catch (RuntimeException re) {
       if (re.getCause() instanceof ParseException) {
         throw (ParseException) re.getCause();
@@ -246,7 +252,10 @@ public final class JavascriptCompiler {
 
     try {
       final Lookup lookup =
-          LOOKUP.defineHiddenClassWithClassData(classWriter.toByteArray(), functions, true);
+          LOOKUP.defineHiddenClassWithClassData(
+              classWriter.toByteArray(),
+              constantsMap.keySet().stream().map(functions::get).toList(),
+              true);
       return invokeConstructor(lookup, lookup.lookupClass(), externalsMap);
     } catch (ReflectiveOperationException exception) {
       throw new IllegalStateException(
@@ -275,9 +284,8 @@ public final class JavascriptCompiler {
    * @throws ParseException on failure to parse
    */
   private ParseTree getAntlrParseTree() throws ParseException {
-    final ANTLRInputStream antlrInputStream = new ANTLRInputStream(sourceText);
     final JavascriptErrorHandlingLexer javascriptLexer =
-        new JavascriptErrorHandlingLexer(antlrInputStream);
+        new JavascriptErrorHandlingLexer(CharStreams.fromString(sourceText));
     javascriptLexer.removeErrorListeners();
     final JavascriptParser javascriptParser =
         new JavascriptParser(new CommonTokenStream(javascriptLexer));
@@ -327,7 +335,8 @@ public final class JavascriptCompiler {
   private void generateClass(
       final ParseTree parseTree,
       final ClassWriter classWriter,
-      final Map<String, Integer> externalsMap)
+      final Map<String, Integer> externalsMap,
+      final Map<String, Integer> constantsMap)
       throws ParseException {
     classWriter.visit(
         CLASSFILE_VERSION,
@@ -357,7 +366,6 @@ public final class JavascriptCompiler {
     // to completely hide the ANTLR visitor we use an anonymous impl:
     new JavascriptBaseVisitor<Void>() {
       private final Deque<Type> typeStack = new ArrayDeque<>();
-      private final Map<String, Integer> constantsMap = new HashMap<>();
 
       @Override
       public Void visitCompile(JavascriptParser.CompileContext ctx) {
@@ -417,12 +425,13 @@ public final class JavascriptCompiler {
             }
 
             // place dynamic constant with MethodHandle on top of stack
+            final int index = constantsMap.computeIfAbsent(text, k -> constantsMap.size());
             gen.visitLdcInsn(
                 new ConstantDynamic(
-                    "func" + constantsMap.computeIfAbsent(text, k -> constantsMap.size()),
+                    ConstantDescs.DEFAULT_NAME,
                     METHOD_HANDLE_TYPE.getDescriptor(),
                     DYNAMIC_CONSTANT_BOOTSTRAP_HANDLE,
-                    text));
+                    index));
 
             // add arguments:
             typeStack.push(Type.DOUBLE_TYPE);
@@ -893,26 +902,6 @@ public final class JavascriptCompiler {
     }
   }
 
-  /**
-   * Bootstrap method for dynamic constants. This returns a {@link MethodHandle} for the {@code
-   * functionName} from the class data passed via {@link Lookup#defineHiddenClassWithClassData}. The
-   * {@code constantName} is ignored.
-   */
-  static MethodHandle dynamicConstantBootstrap(
-      Lookup lookup, String constantName, Class<?> type, String functionName)
-      throws IllegalAccessException {
-    if (type != MethodHandle.class) {
-      throw new IllegalArgumentException("Invalid type of constant: " + type.getName());
-    }
-    final var classData =
-        Objects.requireNonNull(
-            MethodHandles.classData(lookup, ConstantDescs.DEFAULT_NAME, Map.class),
-            "Missing class data for " + lookup);
-    return (MethodHandle)
-        Objects.requireNonNull(
-            classData.get(functionName), "Function does not exist: " + functionName);
-  }
-
   /**
    * Method called from try/catch handler in compiled expression. This patches the stack trace and
    * adds back a hidden frame (including the source code of script as filename).
