@@ -35,7 +35,6 @@ import java.util.List;
 import java.util.Locale;
 import java.util.Objects;
 import java.util.Set;
-import java.util.stream.Collectors;
 import javax.swing.BorderFactory;
 import javax.swing.JButton;
 import javax.swing.JCheckBox;
@@ -140,7 +139,7 @@ public final class SearchPanelProvider implements SearchTabOperator {
 
   private final JButton searchBtn = new JButton();
 
-  private JCheckBox exactHitsCntCB = new JCheckBox();
+  private final JCheckBox exactHitsCntCB = new JCheckBox();
 
   private final JButton mltBtn = new JButton();
 
@@ -614,14 +613,14 @@ public final class SearchPanelProvider implements SearchTabOperator {
 
   private void populateResults(SearchResults res) {
     totalHitsLbl.setText(String.valueOf(res.getTotalHits()));
-    if (res.getTotalHits().value > 0) {
+    if (res.getTotalHits().value() > 0) {
       startLbl.setText(String.valueOf(res.getOffset() + 1));
       endLbl.setText(String.valueOf(res.getOffset() + res.size()));
 
       prevBtn.setEnabled(res.getOffset() > 0);
       nextBtn.setEnabled(
-          res.getTotalHits().relation == TotalHits.Relation.GREATER_THAN_OR_EQUAL_TO
-              || res.getTotalHits().value > res.getOffset() + res.size());
+          res.getTotalHits().relation() == TotalHits.Relation.GREATER_THAN_OR_EQUAL_TO
+              || res.getTotalHits().value() > res.getOffset() + res.size());
 
       if (!indexHandler.getState().readOnly() && indexHandler.getState().hasDirectoryReader()) {
         delBtn.setEnabled(true);
@@ -811,16 +810,10 @@ public final class SearchPanelProvider implements SearchTabOperator {
               });
       operatorRegistry
           .get(FieldValuesTabOperator.class)
-          .ifPresent(
-              operator -> {
-                operator.setFields(searchModel.getFieldNames());
-              });
+          .ifPresent(operator -> operator.setFields(searchModel.getFieldNames()));
       operatorRegistry
           .get(MLTTabOperator.class)
-          .ifPresent(
-              operator -> {
-                operator.setFields(searchModel.getFieldNames());
-              });
+          .ifPresent(operator -> operator.setFields(searchModel.getFieldNames()));
 
       queryStringTA.setText("*:*");
       parsedQueryTA.setText("");
@@ -864,7 +857,7 @@ public final class SearchPanelProvider implements SearchTabOperator {
     VALUES(4),
     MLT(5);
 
-    private int tabIdx;
+    private final int tabIdx;
 
     Tab(int tabIdx) {
       this.tabIdx = tabIdx;
@@ -937,7 +930,7 @@ public final class SearchPanelProvider implements SearchTabOperator {
                       String v = String.join(",", Arrays.asList(e.getValue()));
                       return e.getKey() + "=" + v + ";";
                     })
-                .collect(Collectors.toList());
+                .toList();
         data[i][Column.VALUE.getIndex()] = String.join(" ", concatValues);
       }
     }
